@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -88,7 +88,7 @@ void MailWidget::setMail(const KContacts::Email &email)
     mMailEdit->setText(email.mail());
     const QMap<QString, QStringList> parameters = mEmail.parameters();
     const QStringList value = parameters.value(QStringLiteral("type"));
-    if (value.contains(QStringLiteral("PREF"))) {
+    if (value.contains(QLatin1String("PREF"))) {
         setPreferred(true);
     }
     const QStringList lst = mMailType->selectTypeList();
@@ -118,8 +118,8 @@ KContacts::Email MailWidget::email()
         }
     }
     if (mMailEdit->preferred()) {
-        if (!value.contains(QStringLiteral("PREF"))) {
-            value.append(QStringLiteral("PREF"));
+        if (!value.contains(QLatin1String("PREF"))) {
+            value.append(QLatin1String("PREF"));
         }
     } else {
         value.removeAll(QStringLiteral("PREF"));
